@@ -9,3 +9,9 @@ class Yak(dict):
 	def set(key, value):
 		setattr(Yak, key, value)
 
+	@staticmethod
+	def get(key, default = None):
+		try:
+			return getattr(Yak, key)
+		except:
+			return default
