@@ -212,14 +212,16 @@ def run():
             
 
 
-def gettraceback():
+def gettraceback(level = 0):
     trace = ""
     exception = ""
     exc_list = traceback.format_exception_only (sys.exc_type, sys.exc_value)
+
+    reverse = -1 - level
     for entry in exc_list:
         exception += entry
     tb_list = traceback.format_tb(sys.exc_info()[2])
-    for entry in tb_list[-1]:
+    for entry in tb_list[reverse]:
         trace += entry  
     return trace  
 
